=head1 NAME

FileWiki::Plugin::GenericPageHandler - Generic page handler plugin for FileWiki

=head1 SYNOPSIS

    PLUGINS=GenericPageHandler
    PLUGIN_GENERICPAGEHANDLER_MATCH=\.in$

=head1 DESCRIPTION

Applies the template specified by the TEMPLATE variable to empty
text. This is particulary useful if all you need in your template is
variables (e.g. from vars_provider plugins).

=head1 AUTHOR

Axel Burri <axel@tty0.ch>

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2011-2018 Axel Burri. All rights reserved.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=cut


package FileWiki::Plugin::GenericPageHandler;

use strict;
use warnings;

use base qw( FileWiki::Plugin );

use FileWiki::Logger;
use FileWiki::Filter;

our $VERSION = "0.50";


sub new
{
  my $class = shift;
  my $page = shift;
  my $args = shift;

  my $self = {
    name             => $class,
    page_handler     => 1,
    target_file_ext  => 'html',
    filter => [
      \&FileWiki::Filter::apply_template,
     ],
  };

  bless $self, ref($class) || $class;
  return $self;
}


1;
